pub struct EntryRequirement {
pub slot: String,
pub entry_class: Option<String>,
}Expand description
One trade slot an Entry action reserves and the class it carries, where None is an unclassified entry.
Fields
slot: Stringentry_class: Option<String>Trait Implementations
Sourceimpl Clone for EntryRequirement
impl Clone for EntryRequirement
Sourceimpl Debug for EntryRequirement
impl Debug for EntryRequirement
impl Eq for EntryRequirement
Sourceimpl Ord for EntryRequirement
impl Ord for EntryRequirement
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for EntryRequirement
impl PartialEq for EntryRequirement
Sourceimpl PartialOrd for EntryRequirement
impl PartialOrd for EntryRequirement
impl StructuralPartialEq for EntryRequirement