pub struct MaterialLibrary { /* private fields */ }Implementations
Sourceimpl MaterialLibrary
impl MaterialLibrary
pub fn builtins() -> Self
pub fn with_factory( self, key: impl Into<String>, factory: Arc<dyn MaterialFactory>, ) -> Result<Self, CompileError>
Sourcepub fn numeric_descriptor(
&self,
key: &str,
params: &MaterialArgs,
input_types: &[ValueType],
) -> Result<Option<NumericDescriptor>, String>
pub fn numeric_descriptor( &self, key: &str, params: &MaterialArgs, input_types: &[ValueType], ) -> Result<Option<NumericDescriptor>, String>
Inspect a registered numeric contract using the same validation as evaluator construction. None means the registered factory does not supply a numeric descriptor, not inferred support.
pub fn parameter_schema(&self, key: &str) -> Option<&[ParamSpec]>